@@ -3,6 +3,7 @@ import json
 import pandas as pd
 import numpy as np
 import io
+import logging
 from . import sobjects
 from lht.util import field_types
 from lht.util import stage
@@ -10,6 +11,8 @@ from lht.util import table_creator
 import os
 from lht.util import merge
 
+logger = logging.getLogger(__name__)
+
 
 def create_batch_query(access_info, query):
 	"""Creates a batch query job in Salesforce using the Bulk Query API.
@@ -77,8 +80,8 @@ def query_status(access_info, job_type, job_id):
 			query_statuses.append(results.json())
 			break
 		if results.status_code > 200:
-			print(results.status_code)
-			print("not logged in")
+			logger.error(f"Status code: {results.status_code}")
+			logger.error("not logged in")
 			exit(0)
 		records = len(results.json()['records'])
 		for result in results.json()['records']:
@@ -156,9 +159,7 @@ def get_query_ids(access_info):
 	return jobs
 
 def get_bulk_results_direct(session, access_info, job_id, sobject, schema, table, snowflake_fields=None, database=None, force_full_sync=False):
-	print(f"🔍 get_bulk_results_direct called with force_full_sync={force_full_sync}")
-	print(f"🔍 force_full_sync type: {type(force_full_sync)}")
-	print(f"🔍 force_full_sync value: {repr(force_full_sync)}")
+	logger.debug(f"🔍 get_bulk_results_direct called with force_full_sync={force_full_sync}")
 	
 	# Auto-detect database if not provided
 	if database is None:
@@ -191,7 +192,7 @@ def get_bulk_results_direct(session, access_info, job_id, sobject, schema, table
 	url = access_info['instance_url']+"/services/data/v58.0/jobs/query/{}/results".format(job_id)
 	results = requests.get(url, headers=headers)
 	if results.status_code != 200:
-		print('The job is not ready.  Retry in a few minutes')
+		logger.warning('The job is not ready.  Retry in a few minutes')
 		return None
 	
 	# Always get both field types from describe to ensure we have the correct information
@@ -199,7 +200,7 @@ def get_bulk_results_direct(session, access_info, job_id, sobject, schema, table
 	
 	# Process first batch
 	csv_content = results.text
-	print(f"\n\nPROCESSING BATCH 1")
+	logger.info("PROCESSING BATCH 1")
 	
 	# Load and process data directly (no stage upload needed)
 	# CRITICAL: Force string reading to prevent pandas from converting numeric strings to floats
@@ -212,7 +213,7 @@ def get_bulk_results_direct(session, access_info, job_id, sobject, schema, table
 	
 	# Use centralized table creation utility
 	try:
-		print(f"🚀 Creating table {schema}.{table}...")
+		logger.info(f"🚀 Creating table {schema}.{table}...")
 		table_creator.ensure_table_exists_for_dataframe(
 			session=session,
 			schema=schema,
@@ -222,18 +223,18 @@ def get_bulk_results_direct(session, access_info, job_id, sobject, schema, table
 			force_full_sync=force_full_sync,
 			database=database
 		)
-		print(f"✅ Table creation completed successfully")
+		logger.info(f"✅ Table creation completed successfully")
 				
 		df_str = df.astype(str)
 		df = None
-		print(f"📊 Processing first batch of data")
+		logger.debug(f"📊 Processing first batch of data")
 		session.write_pandas(df_str, schema=schema, table_name="tmp_"+table, auto_create_table=True, overwrite=True, quote_identifiers=False, table_type="temporary")
 		df_str = None
 		transformed_data = merge.transform_and_match_datatypes(session, "tmp_"+table, table)
 		session.sql(f"Insert into {table} select {transformed_data} from tmp_{table}").collect()
-		print(f"✅ First batch loaded successfully")
+		logger.info(f"✅ First batch loaded successfully")
 	except Exception as e:
-		print(f"❌ Failed to create table or load data: {e}")
+		logger.error(f"❌ Failed to create table or load data: {e}")
 		raise Exception(f"Failed to load data into table {schema}.{table}: {e}")
 	
 	# Process remaining batches
@@ -248,7 +249,7 @@ def get_bulk_results_direct(session, access_info, job_id, sobject, schema, table
 		url = access_info['instance_url']+"/services/data/v58.0/jobs/query/{}/results?locator={}".format(job_id, results.headers['Sforce-Locator'])
 		results = requests.get(url, headers=headers)
 		csv_content = results.text
-		print(f"\n\nPROCESSING BATCH {counter}")
+		logger.info(f"PROCESSING BATCH {counter}")
 		
 		# CRITICAL: Force string reading to prevent pandas from converting numeric strings to floats
 		# This prevents "20" from becoming 20.0 and then "20.0"
@@ -257,11 +258,11 @@ def get_bulk_results_direct(session, access_info, job_id, sobject, schema, table
 
 		df_str = df.astype(str)
 		df = None
-		print(f"📊 Processing batch {counter}")
+		logger.debug(f"📊 Processing batch {counter}")
 		session.write_pandas(df_str, schema=schema, table_name="tmp_"+table, auto_create_table=True, overwrite=True, quote_identifiers=False, table_type="temporary")
 		transformed_data = merge.transform_and_match_datatypes(session, "tmp_"+table, table)
 		session.sql(f"Insert into {table} select {transformed_data} from tmp_{table}").collect()
-		print(f"✅ Batch {counter} loaded successfully using save_as_table")
+		logger.info(f"✅ Batch {counter} loaded successfully using save_as_table")
 		df_str = None
 		counter += 1
 	
@@ -292,9 +293,7 @@ def get_bulk_results(session, access_info, job_id, sobject, schema, table, snowf
 		pandas.errors.EmptyDataError: If the CSV data is empty or malformed.
 		snowflake.snowpark.exceptions.SnowparkSQLException: If Snowflake write operation fails.
 	"""
-	print(f"🔍 get_bulk_results called with force_full_sync={force_full_sync}")
-	print(f"🔍 force_full_sync type: {type(force_full_sync)}")
-	print(f"🔍 force_full_sync value: {repr(force_full_sync)}")
+	logger.debug(f"🔍 get_bulk_results called with force_full_sync={force_full_sync}")
 	return get_bulk_results_direct(session, access_info, job_id, sobject, schema, table, snowflake_fields, database, force_full_sync)
 
 def delete_query(access_info, job_id):
@@ -445,7 +444,7 @@ def cleanup_completed_jobs(access_info, max_age_hours=24):
 				
 				if delete_response.status_code == 204:  # Success
 					deleted_count += 1
-					print(f"🗑️ Deleted completed job {job['id']} (age: {job['age_hours']:.1f}h, state: {job['state']})")
+					logger.info(f"🗑️ Deleted completed job {job['id']} (age: {job['age_hours']:.1f}h, state: {job['state']})")
 				else:
 					failed_count += 1
 					failed_jobs.append({
@@ -453,7 +452,7 @@ def cleanup_completed_jobs(access_info, max_age_hours=24):
 						'status_code': delete_response.status_code,
 						'error': delete_response.text
 					})
-					print(f"❌ Failed to delete job {job['id']}: {delete_response.status_code}")
+					logger.error(f"❌ Failed to delete job {job['id']}: {delete_response.status_code}")
 					
 			except Exception as e:
 				failed_count += 1
@@ -461,7 +460,7 @@ def cleanup_completed_jobs(access_info, max_age_hours=24):
 					'id': job['id'],
 					'error': str(e)
 				})
-				print(f"❌ Error deleting job {job['id']}: {e}")
+				logger.error(f"❌ Error deleting job {job['id']}: {e}")
 		
 		cleanup_summary = {
 			'deleted_count': deleted_count,
@@ -471,11 +470,11 @@ def cleanup_completed_jobs(access_info, max_age_hours=24):
 			'failed_jobs': failed_jobs
 		}
 		
-		print(f"🧹 Cleanup completed: {deleted_count} jobs deleted, {failed_count} failed")
+		logger.info(f"🧹 Cleanup completed: {deleted_count} jobs deleted, {failed_count} failed")
 		return cleanup_summary
 		
 	except Exception as e:
-		print(f"❌ Error during job cleanup: {e}")
+		logger.error(f"❌ Error during job cleanup: {e}")
 		return {
 			'deleted_count': 0,
 			'failed_count': 0,
@@ -503,14 +502,14 @@ def delete_specific_job(access_info, job_id):
 		delete_response = requests.delete(delete_url, headers=headers)
 		
 		if delete_response.status_code == 204:
-			print(f"🗑️ Successfully deleted job {job_id}")
+			logger.info(f"🗑️ Successfully deleted job {job_id}")
 			return {
 				'success': True,
 				'job_id': job_id,
 				'message': 'Job deleted successfully'
 			}
 		else:
-			print(f"❌ Failed to delete job {job_id}: {delete_response.status_code}")
+			logger.error(f"❌ Failed to delete job {job_id}: {delete_response.status_code}")
 			return {
 				'success': False,
 				'job_id': job_id,
@@ -519,7 +518,7 @@ def delete_specific_job(access_info, job_id):
 			}
 			
 	except Exception as e:
-		print(f"❌ Error deleting job {job_id}: {e}")
+		logger.error(f"❌ Error deleting job {job_id}: {e}")
 		return {
 			'success': False,
 			'job_id': job_id,
